@@ -48,7 +48,7 @@ get.ml.hz <- function(x, o.names=attr(x, which='original.levels')) {
 	
   # compute a pseudo-brier score using ML hz as the "true" outcome
   # brier's multi-class score : http://en.wikipedia.org/wiki/Brier_score#Original_definition_by_Brier
-  x.bs <- ddply(x, 'name', function(x.i) {
+  x.bs <- ddply(x[!is.na(x$name), ], 'name', function(x.i) {
     # save the gen hz probabilities into new df
     x.pr <- x.i[, safe.names]
     # init new matrix to store most-likely gen hz class
